% umcp-thesis-95.cls

% This file contains if statements and toggles so that the user can
% switch between Masters and PhD, and between draft and official.
% However, I became frustrated with these features and decided to
% scrap them in the versions of this file that I eventually used.
%  --Andy Newman
 
% This is a LaTeX2e class file to comply with specifications of the 
% Thesis and Dissertation Manual of the Graduate School of the
% University of Maryland, College Park, 1995.  The manual is typically
% revised and re-published every five years.  Therefore, a revised class
% file will be required in or around the year 2000.

% AUTHORS
%	Andrew J. Newman
%	Department of Electrical and Computer Engineering; and
%	Institute for Systems Research
%	University of Maryland, College Park
%	newman@isr.umd.edu
%
%	This class file is based on the dissertation.sty file by
%	Pablo A. Straub, 1991, revisions by Aaron E. Naiman, the 
%	umd-thesis.cls file by Thomas J. Stone, 1995, and revisions
%	by Stefan Kehrbaum, 1997.  Some of this file is copied directly 
%	from its predecessors or contains only slight revisions.  

% COPYRIGHT
%	(c) Copyright 1999 by Andrew J. Newman.
%	The original copyright by Pablo A. Straub also applies, as do
%	any copyrights attached to the several subsequent revisions.
%	As with the original copyright, permission is granted to copy
%	and use this material for any purpose except direct commercial
%	advantage.

% MOTIVATION
%	The motivation is to create a LaTeX2e class file that produces
%	a thesis that adheres to specifications as set forth in the manual
%	and can be easily understood, edited, and changed.  The latter
%	reason is important, because (1) guidelines change over time, and
%	(2) the manual is not completely rigid and different users will want 
%	slightly different results.  Improvements to the predecessors to
%	this file have been made in the above areas.  
%
%	We also want to substitute LaTeX commands for the old TeX commands
%	such as \def and \gdef.
%
%	There was an additional goal, in that we also wanted the capability
%	to control all settings from the main thesis document, rather
%	than have to make changes to the class file, in order, for example,
%	to change from draft to official.  However, after achieving only
%	partial successes using various boolean flags, we abandoned that
%	effort, in favor of simply using different class files for draft,
%	official, and official-2sided.  
%
% 	In addition, we deleted all options pertaining to a Masters thesis.
%	This class file could be easily revised for a Masters thesis though.
%	We just thought that it was too unwieldy to include here.
%
%	Class umcp-thesis-95.cls is essentially a modified report class.

% CONTENTS
%
% 1. Class Preliminaries
% 2. Page Setup
% 3. Front Matter
%	3.1. Define parameters
%	3.2. Create front matter
%	3.3. Individual front matter sections
% 4. Headers and Formatting
% 5. Utility Commands
%	5.1. Boolean Flags
%	5.2. Line Spacing
%	5.3. Cross References
%	5.4. Logical
%
% This file does not deal with the back matter, except for formatting
% the header of the bibliography.  No changes are made to the standard
% LaTeX bibliography generation.  No commands are set up for handling
% a glossary, index, or curriculum vitae.  This class file can be 
% extended to handle those sections if needed.
 
%------------------------------------------------------------------------------
% 1. CLASS PRELIMINARIES
%	Set up umcp-thesis-95 class as a modification to the standard 
%	report class.
%------------------------------------------------------------------------------

% IDENTIFICATION

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{umcp-thesis-95}
	      [1999/05/15 v1.0 UMCP Thesis LaTeX document class]

% REQUIRED CODE

\RequirePackage{ifthen}

% DECLARE OPTIONS

\PassOptionsToClass{12pt}{report}
\PassOptionsToClass{letterpaper}{report}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}

% EXECUTE OPTIONS

\ProcessOptions

% LOAD PACKAGE

\LoadClass{report}

%------------------------------------------------------------------------------
% 2. PAGE SETUP 
%	Set margins and line spacing for thesis document.
%	Some settings depend on the 'draft' flag for [draft vs official]. 
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% COMMAND \pagesetup
%	Invoking command \pagesetup sets up the page margins and line
%	spacing according to specifications as set forth in the manual
%	unless flag 'draft' is set to true in which case the settings
%	are made to fit significantly more text on each page.
%------------------------------------------------------------------------------

\newcommand{\pagesetup}{

% MARGINS
% 	We use guidelines from the UMCP thesis and dissertation manual, 1995.
% 	The margins are purposely overstated, so that variations due to 
%	printing and copying do not cause the document to be rejected.
%
%	SPEC		MANUAL		OUR SETTING
%	----		------		-----------
%	Top Margin	>= 1.0in	1.15in
% 	Bottom Margin	>= 1.0in	1.40in
%	Left Margin	>= 1.6in	1.65in
%	Right Margin	>= 1.0in	1.15in

\ifthenelse{\boolean{draft}}
  { \setlength {\topmargin}{0in}            % top margin    1.0 inch
    \setlength {\textheight}{8.5in}         % bottom margin 1.5 inch
    \setlength {\oddsidemargin}{0in}        % left margin   1.0 inch
    \setlength {\textwidth}{6.5in}          % right margin  1.0 inch
  }
  { \setlength {\topmargin}{0.15in}         % top margin    1.15 inch
    \setlength {\textheight}{8.45in}        % bottom margin 1.40 inch
    \setlength {\oddsidemargin}{0.65in}     % left margin   1.65 inch
    \setlength {\textwidth}{5.7in}          % right margin  1.15 inch
    \setlength {\footskip}{0.7in}           % 2 blank lines before pg num.
  }

\setlength {\footnotesep}{14pt}         % baseline skip for footnotes' 1st line
\setlength {\headheight}{0in}           % no header
\setlength {\headsep}{0in}              % no header separation

% LINE SPACING - DEPENDS ON 'DRAFT' FLAG

\ifthenelse{\boolean{draft}}
  { \singlespace }                     	% single spacing for drafts
  { \doublespace }       		% double spacing for official

}	% end \pagesetup

%------------------------------------------------------------------------------
% 3. FRONT MATTER
%------------------------------------------------------------------------------
%
% The front matter includes
%	Abstract			required
%	Title Page			required
%	Copyright Statement
%	Preface or Foreword
%	Dedication
%	Acknowledgements
%	Table of Contents		required
%	List of Tables			required if any exist
%	List of Figures			required if any exist
%	List of Abbreviations
%
% We define parameters and then create the front matter section
% by section.  The format of the abstract page and title page depend
% on the 'masters' flag for [masters vs phd].	
% --------------------------------------------------------------------------

%------------------------------------------------------------------------------
% 	3.1. DEFINE PARAMETERS
% 		There are two kinds of commands that define parameters 
%		for the  front matter:  those  that  provide info (like 
%		\author or \abstractfile) and those that set flags (like 
%		\hascopyright).
%
% 		All commands that provide info redefine an internal command 
%		named  the same but with an initial at sign (e.g., \advisor 
%		redefined \@advisor).  This  idea is standard in LaTeX, so 
%		\author, \title, and \date are not defined here (the standards
% 		are used).
%  
% 		All commands that set flags are used to set the status of the 
%		corresponding ifthenelse command. The parameter must be true
%		or false, or else a `Undefined control sequence command' will 
%		be issued by TeX.
%------------------------------------------------------------------------------

% INFORMATION COMMANDS

\newcommand{\advisor}[1]{\renewcommand{\@advisor}{#1}}
\newcommand{\chairtitle}[1]{\renewcommand{\@chairtitle}{#1}}
\newcommand{\committee}[1]{\renewcommand{\@committee}{#1}}
\newcommand{\department}[1]{\renewcommand{\@department}{#1}}

\newcommand{\masterof}[1]{\renewcommand{\@masterof}{#1}}

\newcommand{\abtitle}[1]{\renewcommand{\@abtitle}{#1}}

\newcommand{\abstractfile}[1]{\renewcommand{\@abstractfile}{#1}}
\newcommand{\prefacefile}[1]{\renewcommand{\@prefacefile}{#1}}
\newcommand{\dedicationfile}[1]{\renewcommand{\@dedicationfile}{#1}}		
\newcommand{\acknowledgementsfile}[1]{\renewcommand{\@acknowledgementsfile}{#1}}	

% DEFAULT VALUES - RE-DEFINE THESE IN YOUR MAIN DOCUMENT

\renewcommand{\@author}{{\it Your Full Name}}
\renewcommand{\@title}{{\it Your Thesis Title}}
\newcommand{\@abtitle}{{\it Your Thesis Title}}
\renewcommand{\@date}{\number\year}
\newcommand{\@advisor}{{\it Academic title and name of advisor}}
\newcommand{\@chairtitle}{Chairman/Advisor}
\newcommand{\@committee}{{\it Academic title and name of members}}
\newcommand{\@department}{Department of Electrical and Computer Engineering}

\newcommand{\@masterof}{Science}		% Could also be 'Art'

 						% Corresponding file name
						% for user to set up:				
\newcommand{\@abstractfile}{abstract}			% abstract.tex
\newcommand{\@prefacefile}{preface}			% preface.tex
\newcommand{\@dedicationfile}{dedication}		% dedication.tex
\newcommand{\@acknowledgementsfile}{acknowledgements}	% acknowledgements.tex

% BOOLEAN SWITCHES		DEFAULT VALUE

\newboolean{hascopyright}	\setboolean{hascopyright}{true}
\newboolean{hasfigures} 	\setboolean{hasfigures}{true}
\newboolean{hastables}  	\setboolean{hastables}{true}

%------------------------------------------------------------------------------
% 	3.2. CREATE FRONT MATTER
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% 	\makefrontmatter
%        
% 	The \makefrontmatter command creates the front matter by conditionally
% 	invoking other commands:
%  
%       	\makeabstract, \maketitlepage, \makecopyrightpage, 
%		\makepreface, \makededication, \makeacknowledgements, 
%		\tableofcontents, \makelistoftables, \makelistoffigures, 
%		\makecommentpage.
%
% 	Page numbering is according to the manual in lowercase roman, arabic 
%	or none.
%------------------------------------------------------------------------------

\newcommand{\makefrontmatter}{

  \pagestyle {empty}				% No page numbers yet

  						% Required Sections:
  \makeabstract 				% Abstract
  \maketitlepage				% Title Page
  \makecopyrightpage				% Copyright statement

  \pagestyle {plain}				% Begin page numbers
  \pagenumbering {roman}			% with roman numerals
  \setcounter {page}{2}				% at page ii

							% Optional Sections:
  \@ifdefined {@prefacefile}{\makepreface}		% Preface
  \@ifdefined {@dedicationfile}{\makededication}	% Dedication
  \@ifdefined {@acknowledgementsfile}			% Acknowledgements
              {\makeacknowledgements}	

  \tableofcontents \newpage			% Table of Contents (always)
  \ifhastables \makelistoftables \fi		% List of Tables (if any)
  \ifhasfigures \makelistoffigures \fi		% List of Figures (if any)

  \pagenumbering {arabic}			% Begin arabic page numbers 
  \setcounter {page}{1}				% at page 1

}	% end \makefrontmatter

%------------------------------------------------------------------------------
% 	3.3. INDIVIDUAL FRONT MATTER SECTIONS
% 		Commands to create different parts of the front matter
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% ABSTRACT PAGE
% 	\makeabstract 
% 	Create the abstract page(s) including title, author, etc.
%	The manual is inconsistent in its specifications here.  It says
%	to center the author's name, but on the sample, the author's name
%	is positioned directly below the thesis title.  The latter looks
%	better, so that's what I used.
%------------------------------------------------------------------------------

\newcommand{\makeabstract}{

  \newpage

  % Center the word ABSTRACT at the top of the page
  \begin{center} 
    \large \rm ABSTRACT   
  \end{center}
  \bigskip

  % Create the abstract page header information.
  % Page layout is different for Masters and PhD, so we use \ifthenelse.

  \ifthenelse{\boolean{masters}}
    % Masters
    {{\singlespace		    
    \noindent
    \begin{tabbing}
      Title of \@thesis: \hspace{35pt} \= \@abtitle \\ \\ 
      Degree candidate:                \> \@author \\ \\ 
      Degree and year:                 \> Master of \@masterof, \@date \\ \\ 
      \@thesis\ directed by:           \> \@advisor \\
				       \> \@department
    \end{tabbing}
    }}  
    % PhD
    {{\singlespace			% control spacing with line breaks \\
    \noindent
    \begin{tabbing}
      Title of \@thesis: \hspace{14pt} 
			    \= \@abtitle \\ \\ \\
      			    \> \@author, Doctor of Philosophy, \@date \\ \\ \\
      \@thesis directed by: \> \@advisor \\
		      	    \> \@department
    \end{tabbing}
    }}

  \hugeskip \bigskip 

  % include abstract from abstractfile now, after all the header info
  \@input{\@abstractfile}	
  \newpage
}	% end \makeabstract

%------------------------------------------------------------------------------
% TITLE PAGE
%	\maketitlepage
%
%------------------------------------------------------------------------------

\newcommand{\maketitlepage}{

  \newpage

  \begin{center} 
    \large \rm \@title 
  \end{center}
  \bigskip

  \begin{center} 
    by \\ \@author 
  \end{center}
  \hugeskip

  {\singlespace
    \begin{center}
      \@thesis submitted to the Faculty of the Graduate School of the \\
      University of Maryland at College Park in partial fulfillment \\
      of the requirements for the degree of \\
      \ifmasters Master of \@masterof \else Doctor of Philosophy \fi \\
      \@date
    \end{center} 
  }
 
  \hugeskip \hugeskip \hugeskip

  \noindent    
  Advisory Committee: 
  \bigskip

  {\singlespace
    \hspace{25pt}   
    \begin{tabular}{l}
      \@advisor, \@chairtitle \\ 
      \@committee 
    \end{tabular}
  }

  \newpage
}	% end \maketitlepage

%------------------------------------------------------------------------------
% COPYRIGHT PAGE
% 	\makecopyrightpage
%	create a copyright page or an empty page
%------------------------------------------------------------------------------

\newcommand{\makecopyrightpage}{
  \newpage

  \mbox{}\par\vfill

  \ifhascopyright
    \begin{center} \copyright Copyright by \\ \@author \\ \@date \end{center}
    \vfill
  \fi

\newpage
}

%------------------------------------------------------------------------------
% PREFACE
% 	\makepreface 
%	create a preface from file \@prefacefile
%------------------------------------------------------------------------------

\newcommand{\makepreface}{
  \newpage

  \begin{center} \large \rm PREFACE \end{center}
  \bigskip

  \@input{\@prefacefile}

  \newpage
}

%------------------------------------------------------------------------------
% DEDICATION
% 	\makededication
%	create a dedication page
%------------------------------------------------------------------------------

\newcommand{\makededication}{
  \newpage

  \begin{center} \large \rm DEDICATION \end{center}
  \bigskip

  \begin{center} \@input{\@dedicationfile} \end{center}		

  \newpage
}

%------------------------------------------------------------------------------
% ACKNOWLEDGEMENTS
% 	\makeacknowledgements
%	create an acknowledgements page
%------------------------------------------------------------------------------

\newcommand{\makeacknowledgements}{
  \newpage
 
  \begin{center} \large \rm ACKNOWLEDGEMENTS \end{center}
  \bigskip

  \@input{\@acknowledgementsfile}				% AJN 5/99

  \newpage
}

%------------------------------------------------------------------------------
% LIST OF TABLES
% 	\makelistoftables 
%	Create the list of tables.  This is the standard LaTeX list of
%	tables with a modified header line.  Is this even necessary???
%------------------------------------------------------------------------------

\newcommand{\makelistoftables}{
  \newpage
  \addcontentsline {toc}{chapter}{List of Tables}
  \listoftables
  \newpage
}

%------------------------------------------------------------------------------
% LIST OF FIGURES
% 	\makelistoffigures
%	create the list of figures
%------------------------------------------------------------------------------

\newcommand{\makelistoffigures}{
  \newpage
  \addcontentsline {toc}{chapter}{List of Figures}
  \listoffigures
  \newpage
}

%------------------------------------------------------------------------------
% COMMENT PAGE
% 	\makecommentpage
%	create a (possibly empty) comment page
%------------------------------------------------------------------------------

\newcommand{\makecommentpage}{
  {\singlespace
  \begin{center}\@title \\[1ex]  \@author \\[1ex] \today \end{center}
  \par\vfill
  \@ifdefined{@comment}{\@comment}
  \par\vfill}
  \begin{center} \large\bf This comment page is not part of the dissertation.
  \\[3ex]
  \end{center}
  \newpage
}

%------------------------------------------------------------------------------
% 4. HEADINGS AND FORMATTING
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% CHAPTER HEADINGS
%	Reduce font size of chapter headings
%------------------------------------------------------------------------------

% \@makechapterhead \@makeschapterhead - create a chapter head
%
% These standard LaTeX commands are redefined here to use not-so-huge type
% There is no particular reason to do this though.

%\renewcommand{\@makechapterhead}[1]{ 
%  \vspace*{50pt} { \parindent 0pt \raggedright
%  \ifnum \c@secnumdepth >\m@ne \Large\bf \@chapapp{} \thechapter \par
%  \vskip 20pt \fi \Large \bf #1\par
%  \nobreak \vskip 40pt } 
%}

%\renewcommand{\@makeschapterhead}[1]{ 
%  \vspace*{50pt} { \parindent 0pt \raggedright
%  \Large \bf #1\par
%  \nobreak \vskip 40pt } 
%}

%------------------------------------------------------------------------------
% HEADER LINES FOR SPECIAL PAGES
%	Header lines for TOC, LOF, LOT, and BIB must be centered and
%	all caps.  LaTeX uses 'CONTENTS' but we need 'TABLE OF CONTENTS'.  
%	LaTeX uses 'REFERENCES' but we need 'BIBLIOGRAPHY'.
%------------------------------------------------------------------------------

\renewcommand{\contentsname}{\centerline{\large \rm TABLE OF CONTENTS}}
\renewcommand{\listfigurename}{\centerline{\large \rm LIST OF FIGURES}}
\renewcommand{\listtablename}{\centerline{\large \rm LIST OF TABLES}}
\renewcommand{\bibname}{\centerline{\large \rm BIBLIOGRAPHY}}

%------------------------------------------------------------------------------
% FORMATTING FOR SPECIAL PAGES
%	Add the header line to each of the standard definitions for
%	TOC, LOF, LOT, and BIB.
%
%	I believe that all of this is completely unnecessary.
%------------------------------------------------------------------------------

% next we modify the definitions of \tableofcontents, \listoffigures,
% and \listoftables.  We need to have \underline{Section}   \underline{Page}
% and so forth....  basically we add the contentsheader line to each 
% of the standard definitions 

%\newcommand{\contentsheader}[2]{
%  \addtocontents{#1}{       
%    \centerline{\underline{#2}\protect\hfill \underline{Page}}
%  }
%}

%\renewcommand{\tableofcontents}
%{       \if@twocolumn
%                \@restonecoltrue\onecolumn
%        \else
%                \@restonecolfalse
%        \fi
%        \chapter*{\contentsname \@mkboth        {\uppercase{\contentsname}}
%                                                {\uppercase{\contentsname}}}
%        \contentsheader{toc}{Section}
%        \@starttoc{toc}
%        \if@restonecol\twocolumn\fi
%}

%\renewcommand{\listoffigures}
%{       \if@twocolumn
%                \@restonecoltrue\onecolumn
%        \else
%                \@restonecolfalse
%        \fi
%        \chapter*{\listfigurename \@mkboth      {\uppercase{\listfigurename}}
%                                                {\uppercase{\listfigurename}}}
%        \contentsheader{lof}{Number}
%        \@starttoc{lof}
%        \if@restonecol\twocolumn\fi
%}

%\renewcommand{\listoftables}
%{       \if@twocolumn
%                \@restonecoltrue\onecolumn
%        \else
%                \@restonecolfalse
%        \fi
%        \chapter*{\listtablename \@mkboth       {\uppercase{\listtablename}}
%                                                {\uppercase{\listtablename}}}
%        \contentsheader{lot}{Number}
%        \@starttoc{lot}
%        \if@restonecol\twocolumn\fi
%\vfill
%}

%------------------------------------------------------------------------------
% 5. UTILITY COMMANDS
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% 	5.1. BOOLEAN FLAGS AND DEFAULT VALUES
%------------------------------------------------------------------------------

% BOOLEAN FLAG		DEFAULT VALUE
\newboolean{draft}	\setboolean{draft}{false}	% DRAFT OR OFFICIAL
\newboolean{masters}	\setboolean{masters}{false}	% MASTERS OR PHD

\newcommand{\@thesis}
  {\ifthenelse{\boolean{masters}}
    {Thesis}
    {Dissertation}
  }

%------------------------------------------------------------------------------
% 	5.2. LINE SPACING
%	 	The \renewcommand{\baselinestretch}{XXX} command is long.
%		So, we define the easier and more intuitive \singlespace and
%		\doublespace, as well as \spacing for arbitrary line spacing.
%		A font changing command is needed for the change to take 
%		effect, so the commands \large \normalsize are included 
%		(but cancel each other out).  
%------------------------------------------------------------------------------

% I do not currently understand why 1.667 (rather than 2.0) is considered
% to be double spacing.

\newcommand{\singlespace}
  {\renewcommand{\baselinestretch}{1.0} \large \normalsize}
\newcommand{\doublespace}
  {\renewcommand{\baselinestretch}{1.667} \large \normalsize}
\newcommand{\spacing}[1]
  {\renewcommand{\baselinestretch}{#1}\large\normalsize}

% \hugeskip - skip twice as much as the TeX command \bigskip
\newcommand{\hugeskip}{\vskip 24pt plus 8pt minus 8pt}

%------------------------------------------------------------------------------
% 	5.3. CROSS REFERENCES
%		Facilitate cross references by creating easy to use commands.
%------------------------------------------------------------------------------

\newcommand{\Chapter}[1]{Chapter~\ref{#1}}
\newcommand{\Section}[1]{Section~\ref{#1}}
\newcommand{\Figure}[1]{Figure~\ref{#1}}
\newcommand{\Table}[1]{Table~\ref{#1}}
\newcommand{\page}[1]{page~\pageref{#1}}

%------------------------------------------------------------------------------
%	5.4. LOGICAL
%------------------------------------------------------------------------------

% \@ifdefined - logical opposite of \ifundefined which is provided by LaTeX
\newcommand{\@ifdefined}[2]{\@ifundefined{#1}{}{#2}}

%------------------------------------------------------------------------------

%% End of file `umcp-thesis-95.cls'.



